@@ -1,4 +1,6 @@
-"""Admin for sliders"""
+"""
+Admin for sliders
+"""
 from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 
